[gnome-settings-daemon/wip/hadess/power-empty-notifications: 3/3] power: Fix text in media player low battery notifications




commit a9ca6ee4582b58126b89ff1ac04cfd0b3d20bc8b
Author: Bastien Nocera <hadess hadess net>
Date:   Wed Jul 21 20:04:02 2021 +0200

    power: Fix text in media player low battery notifications

 plugins/power/gsd-power-manager.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/plugins/power/gsd-power-manager.c b/plugins/power/gsd-power-manager.c
index fd8866db..2daa2497 100644
--- a/plugins/power/gsd-power-manager.c
+++ b/plugins/power/gsd-power-manager.c
@@ -764,8 +764,8 @@ engine_charge_critical (GsdPowerManager *manager, UpDevice *device)
 
         } else if (kind == UP_DEVICE_KIND_MEDIA_PLAYER) {
 
-                /* TRANSLATORS: the cell battery is very low */
-                title = _("Cell phone battery low");
+                /* TRANSLATORS: the media player battery is very low */
+                title = _("Media player battery low");
 
                 /* TRANSLATORS: the device is just going to stop working */
                 if (battery_level == UP_DEVICE_LEVEL_NONE)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]